﻿--[[
	Project: HideParty
	Version: 2.0.4
	Website: http://wow.curseforge.com/addons/hideparty/
	Author: Erfolg

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>. 
]] 

HideParty = LibStub("AceAddon-3.0"):NewAddon("HideParty", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("HideParty")
local db = nil

raidHidden = nil
partyHidden = nil
playerHidden = nil
targetHidden = nil

local options = {
name = "HideParty",
handler = HideParty,
type = "group",
	
	args = {
		
		descrp = {
		type = "description",
		name = L["addon_desc"],
		order = 0,	  
		},

		sep = {
		type = "header",
		name = "",
		order = 1,
		},

		targetEnabled = {
		type = "toggle",
		name = L["HideTarget"],
		desc = L["HideTargetDesc"],
		get = function() return db.targetEnabled end,
		set = function(info, value) 
		local db = HideParty.db.profile				
		db.targetEnabled = value
		HideParty:UpdateFrames()
		end,
		order = 3,
		},

		raidEnabled = {
		type = "toggle",
		name = L["HideRaid"],
		desc = L["HideRaidDesc"],
		get = function() return db.raidEnabled end,
		set = function(info, value) 
		local db = HideParty.db.profile				
		db.raidEnabled = value
		HideParty:UpdateFrames()
		end,
		order = 4,
		},
	
		playerEnabled = {
		type = "toggle",
		name = L["HidePlayer"],
		desc = L["HidePlayerDesc"],
		get = function() return db.playerEnabled end,
		set = function(info, value) 
		local db = HideParty.db.profile				
		db.playerEnabled = value
		HideParty:UpdateFrames()
		end,
		order = 2,
		},

		partyEnabled = {
		type = "toggle",
		name = L["HideParty"],
		desc = L["HidePartyDesc"],
		get = function() return db.partyEnabled end,
		set = function(info, value) 
		local db = HideParty.db.profile				
		db.partyEnabled = value
		HideParty:UpdateFrames()
		end,
		order = 4,
		},
	},
}

local defaults = {
	profile = {
	raidEnabled = true,
	partyEnabled = true,
	playerEnabled = true,
        targetEnabled = true,
	},
}

function HideParty:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("HidePartyDB", defaults, true)
	db = self.db.profile
	LibStub("AceConfig-3.0"):RegisterOptionsTable("HideParty", options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("HideParty", "HideParty")
	self:RegisterChatCommand("hideparty", "ChatCommand")
	print (L["OnLoad"])
	print (L["OnLoad2"])
end

--Functions--
function HideParty:UpdateFrames()
	--Raid 
	if self:IsEnabled() and db.raidEnabled then
		if not raidenabled then 
			isRaidHidden = true
			HideParty:NRaid()
		end
	else
		if isRaidHidden then 
			isRaidHidden = false
			HideParty:SNRaid()
		end
	end
	--Party
	if  self:IsEnabled() and  db.partyEnabled then 
		if not partyEnabled then
	        	isPartyHidden = true
			HideParty:Party()
			HideParty:NParty()
		end
	else
		if not isPartyHidden then
			isPartyHidden = false
			HideParty:SParty()
			HideParty:SNParty()
		end
	end
	--Target
	if self:IsEnabled() and  db.targetEnabled then 
		if not targetEnabled then
			isTargetHidden = true
			HideParty:Target()
		end
	else
		if not isTargetHidden then
			isTargetHidden = false
			HideParty:STarget()
		end
	end
	--Player
	if  self:IsEnabled() and  db.playerEnabled then 
		if not playerEnabled then
			isPlayerHidden = true
			HideParty:Player()
			HideParty:Class()
		end
	else
		if isPlayerHidden then 
			isPlayerHidden = false
			HideParty:SPlayer()
		end
	end
end

function HideParty:OnEnable()
	self:UpdateFrames()
end

function HideParty:OnDisable()
	self:UpdateFrames()
end

function HideParty:OnProfileChanged(db, name)
	self:UpdateFrames()
end

function HideParty:Party()
	for i = 1, 4 do
		local frame = _G["PartyMemberFrame"..i]
		frame:UnregisterAllEvents()
		frame:Hide()
		frame.Show = function() end
	end
end

function HideParty:SParty()
	for i = 1, 4 do
		local frame = _G["PartyMemberFrame"..i]
		frame.Show = nil
		frame:GetScript("OnLoad")(frame)
		frame:GetScript("OnEvent")(frame, "PARTY_MEMBERS_CHANGED")
		PartyMemberFrame_UpdateMember(frame)
	end
end

function HideParty:Player()
	PlayerFrame:UnregisterAllEvents()
	PlayerFrameHealthBar:UnregisterAllEvents()
	PlayerFrameManaBar:UnregisterAllEvents()
	PlayerFrame:Hide()
end

function HideParty:SPlayer()
	PlayerFrame:GetScript("OnLoad")(PlayerFrame)
	PlayerFrame:Show()
	PlayerFrame:GetScript("OnEvent")(PlayerFrame, "PLAYER_ENTERING_WORLD")
	PlayerFrame:GetScript("OnEvent")(PlayerFrame, "PARTY_MEMBERS_CHANGED")
	PlayerFrame.animFinished = true
	PlayerFrame.inSeat = true
	PlayerFrame.inSequence = true
	PlayerFrame_UpdateArt(PlayerFrame)
end

function HideParty:Target()
	TargetFrame:UnregisterAllEvents()
	TargetFrameHealthBar:UnregisterAllEvents()
	TargetFrameManaBar:UnregisterAllEvents()
	TargetFrame:Hide()
end

function HideParty:STarget()
	TargetFrame:GetScript("OnLoad")(TargetFrame)
    	TargetFrame:Show()
	TargetFrame:GetScript("OnEvent")(TargetFrame, "PLAYER_ENTERING_WORLD")
	TargetFrame:GetScript("OnEvent")(TargetFrame, "PARTY_MEMBERS_CHANGED")
	TargetFrame.animFinished = true
	TargetFrame.inSeat = true
	TargetFrame.inSequence = true
	TargetFrame:SetScript("OnShow", function(self) self:Show() end)
end

function HideParty:NParty()
	CompactPartyFrame:UnregisterAllEvents()
	CompactPartyFrame:SetScript("OnShow", function(self) self:Hide() end) 
	CompactPartyFrame:Hide()
end

function HideParty:SNParty()
	if GetNumPartyMembers() > 0 then
		CompactPartyFrame:Show()
	end
	CompactPartyFrame:SetScript("OnShow", function(self) self:Show() end)
end

function HideParty:NRaid()
	CompactRaidFrameManager:UnregisterAllEvents()
	CompactRaidFrameManager:Hide()
	CompactRaidFrameContainer:UnregisterAllEvents()
	CompactRaidFrameContainer:Hide()
end

function HideParty:SNRaid()
	if GetNumRaidMembers() > 0 then
		CompactRaidFrameManager:Show()
	end
	CompactRaidFrameContainer:RegisterEvent("RAID_ROSTER_UPDATE")
	CompactRaidFrameContainer:RegisterEvent("UNIT_PET")
	CompactRaidFrameContainer:Show()
end

function HideParty:Class()
	PaladinPowerBar:UnregisterAllEvents()
	PaladinPowerBar:Hide()
	RuneFrame:UnregisterAllEvents()
	RuneFrame:Hide()
	ComboFrame:UnregisterAllEvents()
	ComboFrame:Hide()
	ShardBarFrame:UnregisterAllEvents()
	ShardBarFrame:Hide()
end

function HideParty:ChatCommand(input)
	if not input or input:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	else
		LibStub("AceConfigCmd-3.0").HandleCommand(HideParty, "hideparty", input)
	end
end
